# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .static_public_key import StaticPublicKey
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JsonWebKey(StaticPublicKey):
    """
    A JSON Web Key that represents the public key used for verifying the JWT signature.
    """

    #: A constant which can be used with the kty property of a JsonWebKey.
    #: This constant has a value of "RSA"
    KTY_RSA = "RSA"

    #: A constant which can be used with the use property of a JsonWebKey.
    #: This constant has a value of "sig"
    USE_SIG = "sig"

    #: A constant which can be used with the key_ops property of a JsonWebKey.
    #: This constant has a value of "verify"
    KEY_OPS_VERIFY = "verify"

    def __init__(self, **kwargs):
        """
        Initializes a new JsonWebKey object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.JsonWebKey.format` attribute
        of this class is ``JSON_WEB_KEY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kid:
            The value to assign to the kid property of this JsonWebKey.
        :type kid: str

        :param format:
            The value to assign to the format property of this JsonWebKey.
            Allowed values for this property are: "JSON_WEB_KEY", "PEM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type format: str

        :param kty:
            The value to assign to the kty property of this JsonWebKey.
            Allowed values for this property are: "RSA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type kty: str

        :param use:
            The value to assign to the use property of this JsonWebKey.
            Allowed values for this property are: "sig", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type use: str

        :param key_ops:
            The value to assign to the key_ops property of this JsonWebKey.
            Allowed values for items in this list are: "verify", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type key_ops: list[str]

        :param alg:
            The value to assign to the alg property of this JsonWebKey.
        :type alg: str

        :param n:
            The value to assign to the n property of this JsonWebKey.
        :type n: str

        :param e:
            The value to assign to the e property of this JsonWebKey.
        :type e: str

        """
        self.swagger_types = {
            'kid': 'str',
            'format': 'str',
            'kty': 'str',
            'use': 'str',
            'key_ops': 'list[str]',
            'alg': 'str',
            'n': 'str',
            'e': 'str'
        }

        self.attribute_map = {
            'kid': 'kid',
            'format': 'format',
            'kty': 'kty',
            'use': 'use',
            'key_ops': 'key_ops',
            'alg': 'alg',
            'n': 'n',
            'e': 'e'
        }

        self._kid = None
        self._format = None
        self._kty = None
        self._use = None
        self._key_ops = None
        self._alg = None
        self._n = None
        self._e = None
        self._format = 'JSON_WEB_KEY'

    @property
    def kty(self):
        """
        **[Required]** Gets the kty of this JsonWebKey.
        The key type.

        Allowed values for this property are: "RSA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The kty of this JsonWebKey.
        :rtype: str
        """
        return self._kty

    @kty.setter
    def kty(self, kty):
        """
        Sets the kty of this JsonWebKey.
        The key type.


        :param kty: The kty of this JsonWebKey.
        :type: str
        """
        allowed_values = ["RSA"]
        if not value_allowed_none_or_none_sentinel(kty, allowed_values):
            kty = 'UNKNOWN_ENUM_VALUE'
        self._kty = kty

    @property
    def use(self):
        """
        Gets the use of this JsonWebKey.
        The intended use of the public key.

        Allowed values for this property are: "sig", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The use of this JsonWebKey.
        :rtype: str
        """
        return self._use

    @use.setter
    def use(self, use):
        """
        Sets the use of this JsonWebKey.
        The intended use of the public key.


        :param use: The use of this JsonWebKey.
        :type: str
        """
        allowed_values = ["sig"]
        if not value_allowed_none_or_none_sentinel(use, allowed_values):
            use = 'UNKNOWN_ENUM_VALUE'
        self._use = use

    @property
    def key_ops(self):
        """
        Gets the key_ops of this JsonWebKey.
        The operations for which this key is to be used.

        Allowed values for items in this list are: "verify", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The key_ops of this JsonWebKey.
        :rtype: list[str]
        """
        return self._key_ops

    @key_ops.setter
    def key_ops(self, key_ops):
        """
        Sets the key_ops of this JsonWebKey.
        The operations for which this key is to be used.


        :param key_ops: The key_ops of this JsonWebKey.
        :type: list[str]
        """
        allowed_values = ["verify"]
        if key_ops:
            key_ops[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in key_ops]
        self._key_ops = key_ops

    @property
    def alg(self):
        """
        **[Required]** Gets the alg of this JsonWebKey.
        The algorithm intended for use with this key.


        :return: The alg of this JsonWebKey.
        :rtype: str
        """
        return self._alg

    @alg.setter
    def alg(self, alg):
        """
        Sets the alg of this JsonWebKey.
        The algorithm intended for use with this key.


        :param alg: The alg of this JsonWebKey.
        :type: str
        """
        self._alg = alg

    @property
    def n(self):
        """
        **[Required]** Gets the n of this JsonWebKey.
        The base64 url encoded modulus of the RSA public key represented
        by this key.


        :return: The n of this JsonWebKey.
        :rtype: str
        """
        return self._n

    @n.setter
    def n(self, n):
        """
        Sets the n of this JsonWebKey.
        The base64 url encoded modulus of the RSA public key represented
        by this key.


        :param n: The n of this JsonWebKey.
        :type: str
        """
        self._n = n

    @property
    def e(self):
        """
        **[Required]** Gets the e of this JsonWebKey.
        The base64 url encoded exponent of the RSA public key represented
        by this key.


        :return: The e of this JsonWebKey.
        :rtype: str
        """
        return self._e

    @e.setter
    def e(self, e):
        """
        Sets the e of this JsonWebKey.
        The base64 url encoded exponent of the RSA public key represented
        by this key.


        :param e: The e of this JsonWebKey.
        :type: str
        """
        self._e = e

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateFolderDetails(object):
    """
    Properties used in folder update operations.
    """

    #: A constant which can be used with the harvest_status property of a UpdateFolderDetails.
    #: This constant has a value of "COMPLETE"
    HARVEST_STATUS_COMPLETE = "COMPLETE"

    #: A constant which can be used with the harvest_status property of a UpdateFolderDetails.
    #: This constant has a value of "ERROR"
    HARVEST_STATUS_ERROR = "ERROR"

    #: A constant which can be used with the harvest_status property of a UpdateFolderDetails.
    #: This constant has a value of "IN_PROGRESS"
    HARVEST_STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the harvest_status property of a UpdateFolderDetails.
    #: This constant has a value of "DEFERRED"
    HARVEST_STATUS_DEFERRED = "DEFERRED"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateFolderDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateFolderDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateFolderDetails.
        :type description: str

        :param parent_folder_key:
            The value to assign to the parent_folder_key property of this UpdateFolderDetails.
        :type parent_folder_key: str

        :param properties:
            The value to assign to the properties property of this UpdateFolderDetails.
        :type properties: dict(str, dict(str, str))

        :param time_external:
            The value to assign to the time_external property of this UpdateFolderDetails.
        :type time_external: datetime

        :param harvest_status:
            The value to assign to the harvest_status property of this UpdateFolderDetails.
            Allowed values for this property are: "COMPLETE", "ERROR", "IN_PROGRESS", "DEFERRED"
        :type harvest_status: str

        :param last_job_key:
            The value to assign to the last_job_key property of this UpdateFolderDetails.
        :type last_job_key: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'parent_folder_key': 'str',
            'properties': 'dict(str, dict(str, str))',
            'time_external': 'datetime',
            'harvest_status': 'str',
            'last_job_key': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'parent_folder_key': 'parentFolderKey',
            'properties': 'properties',
            'time_external': 'timeExternal',
            'harvest_status': 'harvestStatus',
            'last_job_key': 'lastJobKey'
        }

        self._display_name = None
        self._description = None
        self._parent_folder_key = None
        self._properties = None
        self._time_external = None
        self._harvest_status = None
        self._last_job_key = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateFolderDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdateFolderDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateFolderDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdateFolderDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdateFolderDetails.
        Detailed description of a folder.


        :return: The description of this UpdateFolderDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateFolderDetails.
        Detailed description of a folder.


        :param description: The description of this UpdateFolderDetails.
        :type: str
        """
        self._description = description

    @property
    def parent_folder_key(self):
        """
        Gets the parent_folder_key of this UpdateFolderDetails.
        The key of the containing folder.


        :return: The parent_folder_key of this UpdateFolderDetails.
        :rtype: str
        """
        return self._parent_folder_key

    @parent_folder_key.setter
    def parent_folder_key(self, parent_folder_key):
        """
        Sets the parent_folder_key of this UpdateFolderDetails.
        The key of the containing folder.


        :param parent_folder_key: The parent_folder_key of this UpdateFolderDetails.
        :type: str
        """
        self._parent_folder_key = parent_folder_key

    @property
    def properties(self):
        """
        Gets the properties of this UpdateFolderDetails.
        A map of maps that contains the properties which are specific to the folder type. Each folder type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        folders have required properties within the \"default\" category. To determine the set of optional and
        required properties for a folder type, a query can be done on '/types?type=folder' that returns a
        collection of all folder types. The appropriate folder type, which includes definitions of all of
        it's properties, can be identified from this collection.
        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`


        :return: The properties of this UpdateFolderDetails.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this UpdateFolderDetails.
        A map of maps that contains the properties which are specific to the folder type. Each folder type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        folders have required properties within the \"default\" category. To determine the set of optional and
        required properties for a folder type, a query can be done on '/types?type=folder' that returns a
        collection of all folder types. The appropriate folder type, which includes definitions of all of
        it's properties, can be identified from this collection.
        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`


        :param properties: The properties of this UpdateFolderDetails.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    @property
    def time_external(self):
        """
        Gets the time_external of this UpdateFolderDetails.
        Last modified timestamp of this object in the external system.


        :return: The time_external of this UpdateFolderDetails.
        :rtype: datetime
        """
        return self._time_external

    @time_external.setter
    def time_external(self, time_external):
        """
        Sets the time_external of this UpdateFolderDetails.
        Last modified timestamp of this object in the external system.


        :param time_external: The time_external of this UpdateFolderDetails.
        :type: datetime
        """
        self._time_external = time_external

    @property
    def harvest_status(self):
        """
        Gets the harvest_status of this UpdateFolderDetails.
        Harvest status of the folder.

        Allowed values for this property are: "COMPLETE", "ERROR", "IN_PROGRESS", "DEFERRED"


        :return: The harvest_status of this UpdateFolderDetails.
        :rtype: str
        """
        return self._harvest_status

    @harvest_status.setter
    def harvest_status(self, harvest_status):
        """
        Sets the harvest_status of this UpdateFolderDetails.
        Harvest status of the folder.


        :param harvest_status: The harvest_status of this UpdateFolderDetails.
        :type: str
        """
        allowed_values = ["COMPLETE", "ERROR", "IN_PROGRESS", "DEFERRED"]
        if not value_allowed_none_or_none_sentinel(harvest_status, allowed_values):
            raise ValueError(
                "Invalid value for `harvest_status`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._harvest_status = harvest_status

    @property
    def last_job_key(self):
        """
        Gets the last_job_key of this UpdateFolderDetails.
        The key of the last harvest process to update the metadata of this object.


        :return: The last_job_key of this UpdateFolderDetails.
        :rtype: str
        """
        return self._last_job_key

    @last_job_key.setter
    def last_job_key(self, last_job_key):
        """
        Sets the last_job_key of this UpdateFolderDetails.
        The key of the last harvest process to update the metadata of this object.


        :param last_job_key: The last_job_key of this UpdateFolderDetails.
        :type: str
        """
        self._last_job_key = last_job_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AppCatalogListingSummary(object):
    """
    A summary of a listing.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AppCatalogListingSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param listing_id:
            The value to assign to the listing_id property of this AppCatalogListingSummary.
        :type listing_id: str

        :param display_name:
            The value to assign to the display_name property of this AppCatalogListingSummary.
        :type display_name: str

        :param summary:
            The value to assign to the summary property of this AppCatalogListingSummary.
        :type summary: str

        :param publisher_name:
            The value to assign to the publisher_name property of this AppCatalogListingSummary.
        :type publisher_name: str

        """
        self.swagger_types = {
            'listing_id': 'str',
            'display_name': 'str',
            'summary': 'str',
            'publisher_name': 'str'
        }

        self.attribute_map = {
            'listing_id': 'listingId',
            'display_name': 'displayName',
            'summary': 'summary',
            'publisher_name': 'publisherName'
        }

        self._listing_id = None
        self._display_name = None
        self._summary = None
        self._publisher_name = None

    @property
    def listing_id(self):
        """
        Gets the listing_id of this AppCatalogListingSummary.
        the region free ocid of the listing resource.


        :return: The listing_id of this AppCatalogListingSummary.
        :rtype: str
        """
        return self._listing_id

    @listing_id.setter
    def listing_id(self, listing_id):
        """
        Sets the listing_id of this AppCatalogListingSummary.
        the region free ocid of the listing resource.


        :param listing_id: The listing_id of this AppCatalogListingSummary.
        :type: str
        """
        self._listing_id = listing_id

    @property
    def display_name(self):
        """
        Gets the display_name of this AppCatalogListingSummary.
        The display name of the listing.


        :return: The display_name of this AppCatalogListingSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AppCatalogListingSummary.
        The display name of the listing.


        :param display_name: The display_name of this AppCatalogListingSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def summary(self):
        """
        Gets the summary of this AppCatalogListingSummary.
        The short summary for the listing.


        :return: The summary of this AppCatalogListingSummary.
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """
        Sets the summary of this AppCatalogListingSummary.
        The short summary for the listing.


        :param summary: The summary of this AppCatalogListingSummary.
        :type: str
        """
        self._summary = summary

    @property
    def publisher_name(self):
        """
        Gets the publisher_name of this AppCatalogListingSummary.
        The name of the publisher who published this listing.


        :return: The publisher_name of this AppCatalogListingSummary.
        :rtype: str
        """
        return self._publisher_name

    @publisher_name.setter
    def publisher_name(self, publisher_name):
        """
        Sets the publisher_name of this AppCatalogListingSummary.
        The name of the publisher who published this listing.


        :param publisher_name: The publisher_name of this AppCatalogListingSummary.
        :type: str
        """
        self._publisher_name = publisher_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .base64_secret_content_details import Base64SecretContentDetails
from .change_secret_compartment_details import ChangeSecretCompartmentDetails
from .create_secret_details import CreateSecretDetails
from .schedule_secret_deletion_details import ScheduleSecretDeletionDetails
from .schedule_secret_version_deletion_details import ScheduleSecretVersionDeletionDetails
from .secret import Secret
from .secret_content_details import SecretContentDetails
from .secret_expiry_rule import SecretExpiryRule
from .secret_reuse_rule import SecretReuseRule
from .secret_rule import SecretRule
from .secret_summary import SecretSummary
from .secret_version import SecretVersion
from .secret_version_summary import SecretVersionSummary
from .update_secret_details import UpdateSecretDetails

# Maps type names to classes for vault services.
vault_type_mapping = {
    "Base64SecretContentDetails": Base64SecretContentDetails,
    "ChangeSecretCompartmentDetails": ChangeSecretCompartmentDetails,
    "CreateSecretDetails": CreateSecretDetails,
    "ScheduleSecretDeletionDetails": ScheduleSecretDeletionDetails,
    "ScheduleSecretVersionDeletionDetails": ScheduleSecretVersionDeletionDetails,
    "Secret": Secret,
    "SecretContentDetails": SecretContentDetails,
    "SecretExpiryRule": SecretExpiryRule,
    "SecretReuseRule": SecretReuseRule,
    "SecretRule": SecretRule,
    "SecretSummary": SecretSummary,
    "SecretVersion": SecretVersion,
    "SecretVersionSummary": SecretVersionSummary,
    "UpdateSecretDetails": UpdateSecretDetails
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Suppression(object):
    """
    The configuration details for suppressing an alarm.
    For information about alarms, see `Alarms Overview`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#AlarmsOverview
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Suppression object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this Suppression.
        :type description: str

        :param time_suppress_from:
            The value to assign to the time_suppress_from property of this Suppression.
        :type time_suppress_from: datetime

        :param time_suppress_until:
            The value to assign to the time_suppress_until property of this Suppression.
        :type time_suppress_until: datetime

        """
        self.swagger_types = {
            'description': 'str',
            'time_suppress_from': 'datetime',
            'time_suppress_until': 'datetime'
        }

        self.attribute_map = {
            'description': 'description',
            'time_suppress_from': 'timeSuppressFrom',
            'time_suppress_until': 'timeSuppressUntil'
        }

        self._description = None
        self._time_suppress_from = None
        self._time_suppress_until = None

    @property
    def description(self):
        """
        Gets the description of this Suppression.
        Human-readable reason for suppressing alarm notifications.
        It does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        Oracle recommends including tracking information for the event or associated work,
        such as a ticket number.

        Example: `Planned outage due to change IT-1234.`


        :return: The description of this Suppression.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Suppression.
        Human-readable reason for suppressing alarm notifications.
        It does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        Oracle recommends including tracking information for the event or associated work,
        such as a ticket number.

        Example: `Planned outage due to change IT-1234.`


        :param description: The description of this Suppression.
        :type: str
        """
        self._description = description

    @property
    def time_suppress_from(self):
        """
        **[Required]** Gets the time_suppress_from of this Suppression.
        The start date and time for the suppression to take place, inclusive. Format defined by RFC3339.

        Example: `2019-02-01T01:02:29.600Z`


        :return: The time_suppress_from of this Suppression.
        :rtype: datetime
        """
        return self._time_suppress_from

    @time_suppress_from.setter
    def time_suppress_from(self, time_suppress_from):
        """
        Sets the time_suppress_from of this Suppression.
        The start date and time for the suppression to take place, inclusive. Format defined by RFC3339.

        Example: `2019-02-01T01:02:29.600Z`


        :param time_suppress_from: The time_suppress_from of this Suppression.
        :type: datetime
        """
        self._time_suppress_from = time_suppress_from

    @property
    def time_suppress_until(self):
        """
        **[Required]** Gets the time_suppress_until of this Suppression.
        The end date and time for the suppression to take place, inclusive. Format defined by RFC3339.

        Example: `2019-02-01T02:02:29.600Z`


        :return: The time_suppress_until of this Suppression.
        :rtype: datetime
        """
        return self._time_suppress_until

    @time_suppress_until.setter
    def time_suppress_until(self, time_suppress_until):
        """
        Sets the time_suppress_until of this Suppression.
        The end date and time for the suppression to take place, inclusive. Format defined by RFC3339.

        Example: `2019-02-01T02:02:29.600Z`


        :param time_suppress_until: The time_suppress_until of this Suppression.
        :type: datetime
        """
        self._time_suppress_until = time_suppress_until

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AbstractColumn(object):
    """
    Generic column defining all attributes common to all querylanguage columns.
    """

    #: A constant which can be used with the type property of a AbstractColumn.
    #: This constant has a value of "COLUMN"
    TYPE_COLUMN = "COLUMN"

    #: A constant which can be used with the type property of a AbstractColumn.
    #: This constant has a value of "CHART_COLUMN"
    TYPE_CHART_COLUMN = "CHART_COLUMN"

    #: A constant which can be used with the type property of a AbstractColumn.
    #: This constant has a value of "CHART_DATA_COLUMN"
    TYPE_CHART_DATA_COLUMN = "CHART_DATA_COLUMN"

    #: A constant which can be used with the type property of a AbstractColumn.
    #: This constant has a value of "TIME_COLUMN"
    TYPE_TIME_COLUMN = "TIME_COLUMN"

    #: A constant which can be used with the type property of a AbstractColumn.
    #: This constant has a value of "TREND_COLUMN"
    TYPE_TREND_COLUMN = "TREND_COLUMN"

    #: A constant which can be used with the type property of a AbstractColumn.
    #: This constant has a value of "CLASSIFY_COLUMN"
    TYPE_CLASSIFY_COLUMN = "CLASSIFY_COLUMN"

    #: A constant which can be used with the sub_system property of a AbstractColumn.
    #: This constant has a value of "LOG"
    SUB_SYSTEM_LOG = "LOG"

    #: A constant which can be used with the value_type property of a AbstractColumn.
    #: This constant has a value of "BOOLEAN"
    VALUE_TYPE_BOOLEAN = "BOOLEAN"

    #: A constant which can be used with the value_type property of a AbstractColumn.
    #: This constant has a value of "STRING"
    VALUE_TYPE_STRING = "STRING"

    #: A constant which can be used with the value_type property of a AbstractColumn.
    #: This constant has a value of "DOUBLE"
    VALUE_TYPE_DOUBLE = "DOUBLE"

    #: A constant which can be used with the value_type property of a AbstractColumn.
    #: This constant has a value of "FLOAT"
    VALUE_TYPE_FLOAT = "FLOAT"

    #: A constant which can be used with the value_type property of a AbstractColumn.
    #: This constant has a value of "LONG"
    VALUE_TYPE_LONG = "LONG"

    #: A constant which can be used with the value_type property of a AbstractColumn.
    #: This constant has a value of "INTEGER"
    VALUE_TYPE_INTEGER = "INTEGER"

    #: A constant which can be used with the value_type property of a AbstractColumn.
    #: This constant has a value of "TIMESTAMP"
    VALUE_TYPE_TIMESTAMP = "TIMESTAMP"

    #: A constant which can be used with the value_type property of a AbstractColumn.
    #: This constant has a value of "FACET"
    VALUE_TYPE_FACET = "FACET"

    def __init__(self, **kwargs):
        """
        Initializes a new AbstractColumn object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.log_analytics.models.TimeColumn`
        * :class:`~oci.log_analytics.models.ClassifyColumn`
        * :class:`~oci.log_analytics.models.TrendColumn`
        * :class:`~oci.log_analytics.models.Column`
        * :class:`~oci.log_analytics.models.ChartColumn`
        * :class:`~oci.log_analytics.models.ChartDataColumn`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AbstractColumn.
            Allowed values for this property are: "COLUMN", "CHART_COLUMN", "CHART_DATA_COLUMN", "TIME_COLUMN", "TREND_COLUMN", "CLASSIFY_COLUMN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param display_name:
            The value to assign to the display_name property of this AbstractColumn.
        :type display_name: str

        :param sub_system:
            The value to assign to the sub_system property of this AbstractColumn.
            Allowed values for this property are: "LOG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type sub_system: str

        :param values:
            The value to assign to the values property of this AbstractColumn.
        :type values: list[FieldValue]

        :param is_list_of_values:
            The value to assign to the is_list_of_values property of this AbstractColumn.
        :type is_list_of_values: bool

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this AbstractColumn.
        :type is_multi_valued: bool

        :param is_groupable:
            The value to assign to the is_groupable property of this AbstractColumn.
        :type is_groupable: bool

        :param is_evaluable:
            The value to assign to the is_evaluable property of this AbstractColumn.
        :type is_evaluable: bool

        :param value_type:
            The value to assign to the value_type property of this AbstractColumn.
            Allowed values for this property are: "BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type value_type: str

        :param original_display_name:
            The value to assign to the original_display_name property of this AbstractColumn.
        :type original_display_name: str

        :param internal_name:
            The value to assign to the internal_name property of this AbstractColumn.
        :type internal_name: str

        """
        self.swagger_types = {
            'type': 'str',
            'display_name': 'str',
            'sub_system': 'str',
            'values': 'list[FieldValue]',
            'is_list_of_values': 'bool',
            'is_multi_valued': 'bool',
            'is_groupable': 'bool',
            'is_evaluable': 'bool',
            'value_type': 'str',
            'original_display_name': 'str',
            'internal_name': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'display_name': 'displayName',
            'sub_system': 'subSystem',
            'values': 'values',
            'is_list_of_values': 'isListOfValues',
            'is_multi_valued': 'isMultiValued',
            'is_groupable': 'isGroupable',
            'is_evaluable': 'isEvaluable',
            'value_type': 'valueType',
            'original_display_name': 'originalDisplayName',
            'internal_name': 'internalName'
        }

        self._type = None
        self._display_name = None
        self._sub_system = None
        self._values = None
        self._is_list_of_values = None
        self._is_multi_valued = None
        self._is_groupable = None
        self._is_evaluable = None
        self._value_type = None
        self._original_display_name = None
        self._internal_name = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'TIME_COLUMN':
            return 'TimeColumn'

        if type == 'CLASSIFY_COLUMN':
            return 'ClassifyColumn'

        if type == 'TREND_COLUMN':
            return 'TrendColumn'

        if type == 'COLUMN':
            return 'Column'

        if type == 'CHART_COLUMN':
            return 'ChartColumn'

        if type == 'CHART_DATA_COLUMN':
            return 'ChartDataColumn'
        else:
            return 'AbstractColumn'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this AbstractColumn.
        Column classification when column requires special designation.

        Allowed values for this property are: "COLUMN", "CHART_COLUMN", "CHART_DATA_COLUMN", "TIME_COLUMN", "TREND_COLUMN", "CLASSIFY_COLUMN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this AbstractColumn.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AbstractColumn.
        Column classification when column requires special designation.


        :param type: The type of this AbstractColumn.
        :type: str
        """
        allowed_values = ["COLUMN", "CHART_COLUMN", "CHART_DATA_COLUMN", "TIME_COLUMN", "TREND_COLUMN", "CLASSIFY_COLUMN"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def display_name(self):
        """
        Gets the display_name of this AbstractColumn.
        Column display name - will be alias if column is renamed by queryStrng.


        :return: The display_name of this AbstractColumn.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AbstractColumn.
        Column display name - will be alias if column is renamed by queryStrng.


        :param display_name: The display_name of this AbstractColumn.
        :type: str
        """
        self._display_name = display_name

    @property
    def sub_system(self):
        """
        Gets the sub_system of this AbstractColumn.
        Subsystem column belongs to.

        Allowed values for this property are: "LOG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The sub_system of this AbstractColumn.
        :rtype: str
        """
        return self._sub_system

    @sub_system.setter
    def sub_system(self, sub_system):
        """
        Sets the sub_system of this AbstractColumn.
        Subsystem column belongs to.


        :param sub_system: The sub_system of this AbstractColumn.
        :type: str
        """
        allowed_values = ["LOG"]
        if not value_allowed_none_or_none_sentinel(sub_system, allowed_values):
            sub_system = 'UNKNOWN_ENUM_VALUE'
        self._sub_system = sub_system

    @property
    def values(self):
        """
        Gets the values of this AbstractColumn.
        If the column is a 'List of Values' column, this array contains the field values that are applicable to query results or all if no filters applied.


        :return: The values of this AbstractColumn.
        :rtype: list[FieldValue]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this AbstractColumn.
        If the column is a 'List of Values' column, this array contains the field values that are applicable to query results or all if no filters applied.


        :param values: The values of this AbstractColumn.
        :type: list[FieldValue]
        """
        self._values = values

    @property
    def is_list_of_values(self):
        """
        Gets the is_list_of_values of this AbstractColumn.
        Identifies if all values in this column come from a pre-defined list of values.


        :return: The is_list_of_values of this AbstractColumn.
        :rtype: bool
        """
        return self._is_list_of_values

    @is_list_of_values.setter
    def is_list_of_values(self, is_list_of_values):
        """
        Sets the is_list_of_values of this AbstractColumn.
        Identifies if all values in this column come from a pre-defined list of values.


        :param is_list_of_values: The is_list_of_values of this AbstractColumn.
        :type: bool
        """
        self._is_list_of_values = is_list_of_values

    @property
    def is_multi_valued(self):
        """
        Gets the is_multi_valued of this AbstractColumn.
        Identifies if this column allows multiple values to exist in a single row.


        :return: The is_multi_valued of this AbstractColumn.
        :rtype: bool
        """
        return self._is_multi_valued

    @is_multi_valued.setter
    def is_multi_valued(self, is_multi_valued):
        """
        Sets the is_multi_valued of this AbstractColumn.
        Identifies if this column allows multiple values to exist in a single row.


        :param is_multi_valued: The is_multi_valued of this AbstractColumn.
        :type: bool
        """
        self._is_multi_valued = is_multi_valued

    @property
    def is_groupable(self):
        """
        Gets the is_groupable of this AbstractColumn.
        Identifies if this column can be used as a grouping field in any grouping command.


        :return: The is_groupable of this AbstractColumn.
        :rtype: bool
        """
        return self._is_groupable

    @is_groupable.setter
    def is_groupable(self, is_groupable):
        """
        Sets the is_groupable of this AbstractColumn.
        Identifies if this column can be used as a grouping field in any grouping command.


        :param is_groupable: The is_groupable of this AbstractColumn.
        :type: bool
        """
        self._is_groupable = is_groupable

    @property
    def is_evaluable(self):
        """
        Gets the is_evaluable of this AbstractColumn.
        Identifies if this column can be used as an expression parameter in any command that accepts querylanguage expressions.


        :return: The is_evaluable of this AbstractColumn.
        :rtype: bool
        """
        return self._is_evaluable

    @is_evaluable.setter
    def is_evaluable(self, is_evaluable):
        """
        Sets the is_evaluable of this AbstractColumn.
        Identifies if this column can be used as an expression parameter in any command that accepts querylanguage expressions.


        :param is_evaluable: The is_evaluable of this AbstractColumn.
        :type: bool
        """
        self._is_evaluable = is_evaluable

    @property
    def value_type(self):
        """
        Gets the value_type of this AbstractColumn.
        Field denoting column data type.

        Allowed values for this property are: "BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The value_type of this AbstractColumn.
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """
        Sets the value_type of this AbstractColumn.
        Field denoting column data type.


        :param value_type: The value_type of this AbstractColumn.
        :type: str
        """
        allowed_values = ["BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET"]
        if not value_allowed_none_or_none_sentinel(value_type, allowed_values):
            value_type = 'UNKNOWN_ENUM_VALUE'
        self._value_type = value_type

    @property
    def original_display_name(self):
        """
        Gets the original_display_name of this AbstractColumn.
        Same as displayName unless column renamed in which case this will hold the original display name for the column.


        :return: The original_display_name of this AbstractColumn.
        :rtype: str
        """
        return self._original_display_name

    @original_display_name.setter
    def original_display_name(self, original_display_name):
        """
        Sets the original_display_name of this AbstractColumn.
        Same as displayName unless column renamed in which case this will hold the original display name for the column.


        :param original_display_name: The original_display_name of this AbstractColumn.
        :type: str
        """
        self._original_display_name = original_display_name

    @property
    def internal_name(self):
        """
        Gets the internal_name of this AbstractColumn.
        Internal identifier for the column.


        :return: The internal_name of this AbstractColumn.
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """
        Sets the internal_name of this AbstractColumn.
        Internal identifier for the column.


        :param internal_name: The internal_name of this AbstractColumn.
        :type: str
        """
        self._internal_name = internal_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateExternalBackupJobDetails(object):
    """
    CreateExternalBackupJobDetails model.
    """

    #: A constant which can be used with the database_mode property of a CreateExternalBackupJobDetails.
    #: This constant has a value of "SI"
    DATABASE_MODE_SI = "SI"

    #: A constant which can be used with the database_mode property of a CreateExternalBackupJobDetails.
    #: This constant has a value of "RAC"
    DATABASE_MODE_RAC = "RAC"

    #: A constant which can be used with the database_edition property of a CreateExternalBackupJobDetails.
    #: This constant has a value of "STANDARD_EDITION"
    DATABASE_EDITION_STANDARD_EDITION = "STANDARD_EDITION"

    #: A constant which can be used with the database_edition property of a CreateExternalBackupJobDetails.
    #: This constant has a value of "ENTERPRISE_EDITION"
    DATABASE_EDITION_ENTERPRISE_EDITION = "ENTERPRISE_EDITION"

    #: A constant which can be used with the database_edition property of a CreateExternalBackupJobDetails.
    #: This constant has a value of "ENTERPRISE_EDITION_HIGH_PERFORMANCE"
    DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = "ENTERPRISE_EDITION_HIGH_PERFORMANCE"

    #: A constant which can be used with the database_edition property of a CreateExternalBackupJobDetails.
    #: This constant has a value of "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"
    DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateExternalBackupJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this CreateExternalBackupJobDetails.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateExternalBackupJobDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateExternalBackupJobDetails.
        :type display_name: str

        :param db_version:
            The value to assign to the db_version property of this CreateExternalBackupJobDetails.
        :type db_version: str

        :param db_name:
            The value to assign to the db_name property of this CreateExternalBackupJobDetails.
        :type db_name: str

        :param db_unique_name:
            The value to assign to the db_unique_name property of this CreateExternalBackupJobDetails.
        :type db_unique_name: str

        :param pdb_name:
            The value to assign to the pdb_name property of this CreateExternalBackupJobDetails.
        :type pdb_name: str

        :param external_database_identifier:
            The value to assign to the external_database_identifier property of this CreateExternalBackupJobDetails.
        :type external_database_identifier: int

        :param character_set:
            The value to assign to the character_set property of this CreateExternalBackupJobDetails.
        :type character_set: str

        :param ncharacter_set:
            The value to assign to the ncharacter_set property of this CreateExternalBackupJobDetails.
        :type ncharacter_set: str

        :param database_mode:
            The value to assign to the database_mode property of this CreateExternalBackupJobDetails.
            Allowed values for this property are: "SI", "RAC"
        :type database_mode: str

        :param database_edition:
            The value to assign to the database_edition property of this CreateExternalBackupJobDetails.
            Allowed values for this property are: "STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"
        :type database_edition: str

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'db_version': 'str',
            'db_name': 'str',
            'db_unique_name': 'str',
            'pdb_name': 'str',
            'external_database_identifier': 'int',
            'character_set': 'str',
            'ncharacter_set': 'str',
            'database_mode': 'str',
            'database_edition': 'str'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'db_version': 'dbVersion',
            'db_name': 'dbName',
            'db_unique_name': 'dbUniqueName',
            'pdb_name': 'pdbName',
            'external_database_identifier': 'externalDatabaseIdentifier',
            'character_set': 'characterSet',
            'ncharacter_set': 'ncharacterSet',
            'database_mode': 'databaseMode',
            'database_edition': 'databaseEdition'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._display_name = None
        self._db_version = None
        self._db_name = None
        self._db_unique_name = None
        self._pdb_name = None
        self._external_database_identifier = None
        self._character_set = None
        self._ncharacter_set = None
        self._database_mode = None
        self._database_edition = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this CreateExternalBackupJobDetails.
        The targeted availability domain for the backup.


        :return: The availability_domain of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CreateExternalBackupJobDetails.
        The targeted availability domain for the backup.


        :param availability_domain: The availability_domain of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateExternalBackupJobDetails.
        The `OCID`__ of the compartment where this backup should be created.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateExternalBackupJobDetails.
        The `OCID`__ of the compartment where this backup should be created.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateExternalBackupJobDetails.
        A user-friendly name for the backup. This name does not have to be unique.


        :return: The display_name of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateExternalBackupJobDetails.
        A user-friendly name for the backup. This name does not have to be unique.


        :param display_name: The display_name of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def db_version(self):
        """
        **[Required]** Gets the db_version of this CreateExternalBackupJobDetails.
        A valid Oracle Database version.


        :return: The db_version of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._db_version

    @db_version.setter
    def db_version(self, db_version):
        """
        Sets the db_version of this CreateExternalBackupJobDetails.
        A valid Oracle Database version.


        :param db_version: The db_version of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._db_version = db_version

    @property
    def db_name(self):
        """
        **[Required]** Gets the db_name of this CreateExternalBackupJobDetails.
        The name of the database from which the backup is being taken.


        :return: The db_name of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """
        Sets the db_name of this CreateExternalBackupJobDetails.
        The name of the database from which the backup is being taken.


        :param db_name: The db_name of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._db_name = db_name

    @property
    def db_unique_name(self):
        """
        Gets the db_unique_name of this CreateExternalBackupJobDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :return: The db_unique_name of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._db_unique_name

    @db_unique_name.setter
    def db_unique_name(self, db_unique_name):
        """
        Sets the db_unique_name of this CreateExternalBackupJobDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :param db_unique_name: The db_unique_name of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._db_unique_name = db_unique_name

    @property
    def pdb_name(self):
        """
        Gets the pdb_name of this CreateExternalBackupJobDetails.
        The pluggable database name.


        :return: The pdb_name of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._pdb_name

    @pdb_name.setter
    def pdb_name(self, pdb_name):
        """
        Sets the pdb_name of this CreateExternalBackupJobDetails.
        The pluggable database name.


        :param pdb_name: The pdb_name of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._pdb_name = pdb_name

    @property
    def external_database_identifier(self):
        """
        **[Required]** Gets the external_database_identifier of this CreateExternalBackupJobDetails.
        The `DBID` of the Oracle Database being backed up.


        :return: The external_database_identifier of this CreateExternalBackupJobDetails.
        :rtype: int
        """
        return self._external_database_identifier

    @external_database_identifier.setter
    def external_database_identifier(self, external_database_identifier):
        """
        Sets the external_database_identifier of this CreateExternalBackupJobDetails.
        The `DBID` of the Oracle Database being backed up.


        :param external_database_identifier: The external_database_identifier of this CreateExternalBackupJobDetails.
        :type: int
        """
        self._external_database_identifier = external_database_identifier

    @property
    def character_set(self):
        """
        **[Required]** Gets the character_set of this CreateExternalBackupJobDetails.
        The character set for the database.


        :return: The character_set of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._character_set

    @character_set.setter
    def character_set(self, character_set):
        """
        Sets the character_set of this CreateExternalBackupJobDetails.
        The character set for the database.


        :param character_set: The character_set of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._character_set = character_set

    @property
    def ncharacter_set(self):
        """
        **[Required]** Gets the ncharacter_set of this CreateExternalBackupJobDetails.
        The national character set for the database.


        :return: The ncharacter_set of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._ncharacter_set

    @ncharacter_set.setter
    def ncharacter_set(self, ncharacter_set):
        """
        Sets the ncharacter_set of this CreateExternalBackupJobDetails.
        The national character set for the database.


        :param ncharacter_set: The ncharacter_set of this CreateExternalBackupJobDetails.
        :type: str
        """
        self._ncharacter_set = ncharacter_set

    @property
    def database_mode(self):
        """
        **[Required]** Gets the database_mode of this CreateExternalBackupJobDetails.
        The mode (single instance or RAC) of the database being backed up.

        Allowed values for this property are: "SI", "RAC"


        :return: The database_mode of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._database_mode

    @database_mode.setter
    def database_mode(self, database_mode):
        """
        Sets the database_mode of this CreateExternalBackupJobDetails.
        The mode (single instance or RAC) of the database being backed up.


        :param database_mode: The database_mode of this CreateExternalBackupJobDetails.
        :type: str
        """
        allowed_values = ["SI", "RAC"]
        if not value_allowed_none_or_none_sentinel(database_mode, allowed_values):
            raise ValueError(
                "Invalid value for `database_mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._database_mode = database_mode

    @property
    def database_edition(self):
        """
        **[Required]** Gets the database_edition of this CreateExternalBackupJobDetails.
        The Oracle Database edition to use for creating a database from this standalone backup.
        Note that 2-node RAC DB systems require Enterprise Edition - Extreme Performance.

        Allowed values for this property are: "STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"


        :return: The database_edition of this CreateExternalBackupJobDetails.
        :rtype: str
        """
        return self._database_edition

    @database_edition.setter
    def database_edition(self, database_edition):
        """
        Sets the database_edition of this CreateExternalBackupJobDetails.
        The Oracle Database edition to use for creating a database from this standalone backup.
        Note that 2-node RAC DB systems require Enterprise Edition - Extreme Performance.


        :param database_edition: The database_edition of this CreateExternalBackupJobDetails.
        :type: str
        """
        allowed_values = ["STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"]
        if not value_allowed_none_or_none_sentinel(database_edition, allowed_values):
            raise ValueError(
                "Invalid value for `database_edition`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._database_edition = database_edition

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Peer(object):
    """
    A Peer details
    """

    #: A constant which can be used with the lifecycle_state property of a Peer.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Peer.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Peer.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Peer object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param peer_key:
            The value to assign to the peer_key property of this Peer.
        :type peer_key: str

        :param role:
            The value to assign to the role property of this Peer.
        :type role: str

        :param alias:
            The value to assign to the alias property of this Peer.
        :type alias: str

        :param ocpu_allocation_param:
            The value to assign to the ocpu_allocation_param property of this Peer.
        :type ocpu_allocation_param: OcpuAllocationNumberParam

        :param host:
            The value to assign to the host property of this Peer.
        :type host: str

        :param ad:
            The value to assign to the ad property of this Peer.
        :type ad: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Peer.
            Allowed values for this property are: "ACTIVE", "INACTIVE", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'peer_key': 'str',
            'role': 'str',
            'alias': 'str',
            'ocpu_allocation_param': 'OcpuAllocationNumberParam',
            'host': 'str',
            'ad': 'str',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'peer_key': 'peerKey',
            'role': 'role',
            'alias': 'alias',
            'ocpu_allocation_param': 'ocpuAllocationParam',
            'host': 'host',
            'ad': 'ad',
            'lifecycle_state': 'lifecycleState'
        }

        self._peer_key = None
        self._role = None
        self._alias = None
        self._ocpu_allocation_param = None
        self._host = None
        self._ad = None
        self._lifecycle_state = None

    @property
    def peer_key(self):
        """
        **[Required]** Gets the peer_key of this Peer.
        peer identifier


        :return: The peer_key of this Peer.
        :rtype: str
        """
        return self._peer_key

    @peer_key.setter
    def peer_key(self, peer_key):
        """
        Sets the peer_key of this Peer.
        peer identifier


        :param peer_key: The peer_key of this Peer.
        :type: str
        """
        self._peer_key = peer_key

    @property
    def role(self):
        """
        **[Required]** Gets the role of this Peer.
        Peer role


        :return: The role of this Peer.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this Peer.
        Peer role


        :param role: The role of this Peer.
        :type: str
        """
        self._role = role

    @property
    def alias(self):
        """
        Gets the alias of this Peer.
        peer alias


        :return: The alias of this Peer.
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """
        Sets the alias of this Peer.
        peer alias


        :param alias: The alias of this Peer.
        :type: str
        """
        self._alias = alias

    @property
    def ocpu_allocation_param(self):
        """
        Gets the ocpu_allocation_param of this Peer.

        :return: The ocpu_allocation_param of this Peer.
        :rtype: OcpuAllocationNumberParam
        """
        return self._ocpu_allocation_param

    @ocpu_allocation_param.setter
    def ocpu_allocation_param(self, ocpu_allocation_param):
        """
        Sets the ocpu_allocation_param of this Peer.

        :param ocpu_allocation_param: The ocpu_allocation_param of this Peer.
        :type: OcpuAllocationNumberParam
        """
        self._ocpu_allocation_param = ocpu_allocation_param

    @property
    def host(self):
        """
        **[Required]** Gets the host of this Peer.
        Host on which the Peer exists


        :return: The host of this Peer.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this Peer.
        Host on which the Peer exists


        :param host: The host of this Peer.
        :type: str
        """
        self._host = host

    @property
    def ad(self):
        """
        **[Required]** Gets the ad of this Peer.
        Availability Domain of peer


        :return: The ad of this Peer.
        :rtype: str
        """
        return self._ad

    @ad.setter
    def ad(self, ad):
        """
        Sets the ad of this Peer.
        Availability Domain of peer


        :param ad: The ad of this Peer.
        :type: str
        """
        self._ad = ad

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Peer.
        The current state of the peer.

        Allowed values for this property are: "ACTIVE", "INACTIVE", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Peer.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Peer.
        The current state of the peer.


        :param lifecycle_state: The lifecycle_state of this Peer.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_column import AbstractColumn
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TrendColumn(AbstractColumn):
    """
    Result column, that contains time series data points in each row. The column includes the time stamps as additional field in column header.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TrendColumn object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.TrendColumn.type` attribute
        of this class is ``TREND_COLUMN`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this TrendColumn.
            Allowed values for this property are: "COLUMN", "CHART_COLUMN", "CHART_DATA_COLUMN", "TIME_COLUMN", "TREND_COLUMN", "CLASSIFY_COLUMN"
        :type type: str

        :param display_name:
            The value to assign to the display_name property of this TrendColumn.
        :type display_name: str

        :param sub_system:
            The value to assign to the sub_system property of this TrendColumn.
            Allowed values for this property are: "LOG"
        :type sub_system: str

        :param values:
            The value to assign to the values property of this TrendColumn.
        :type values: list[FieldValue]

        :param is_list_of_values:
            The value to assign to the is_list_of_values property of this TrendColumn.
        :type is_list_of_values: bool

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this TrendColumn.
        :type is_multi_valued: bool

        :param is_groupable:
            The value to assign to the is_groupable property of this TrendColumn.
        :type is_groupable: bool

        :param is_evaluable:
            The value to assign to the is_evaluable property of this TrendColumn.
        :type is_evaluable: bool

        :param value_type:
            The value to assign to the value_type property of this TrendColumn.
            Allowed values for this property are: "BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET"
        :type value_type: str

        :param original_display_name:
            The value to assign to the original_display_name property of this TrendColumn.
        :type original_display_name: str

        :param internal_name:
            The value to assign to the internal_name property of this TrendColumn.
        :type internal_name: str

        :param interval_gap:
            The value to assign to the interval_gap property of this TrendColumn.
        :type interval_gap: str

        :param intervals:
            The value to assign to the intervals property of this TrendColumn.
        :type intervals: list[int]

        :param total_interval_counts:
            The value to assign to the total_interval_counts property of this TrendColumn.
        :type total_interval_counts: list[int]

        :param total_interval_counts_after_filter:
            The value to assign to the total_interval_counts_after_filter property of this TrendColumn.
        :type total_interval_counts_after_filter: list[int]

        :param interval_group_counts:
            The value to assign to the interval_group_counts property of this TrendColumn.
        :type interval_group_counts: list[int]

        :param interval_group_counts_after_filter:
            The value to assign to the interval_group_counts_after_filter property of this TrendColumn.
        :type interval_group_counts_after_filter: list[int]

        """
        self.swagger_types = {
            'type': 'str',
            'display_name': 'str',
            'sub_system': 'str',
            'values': 'list[FieldValue]',
            'is_list_of_values': 'bool',
            'is_multi_valued': 'bool',
            'is_groupable': 'bool',
            'is_evaluable': 'bool',
            'value_type': 'str',
            'original_display_name': 'str',
            'internal_name': 'str',
            'interval_gap': 'str',
            'intervals': 'list[int]',
            'total_interval_counts': 'list[int]',
            'total_interval_counts_after_filter': 'list[int]',
            'interval_group_counts': 'list[int]',
            'interval_group_counts_after_filter': 'list[int]'
        }

        self.attribute_map = {
            'type': 'type',
            'display_name': 'displayName',
            'sub_system': 'subSystem',
            'values': 'values',
            'is_list_of_values': 'isListOfValues',
            'is_multi_valued': 'isMultiValued',
            'is_groupable': 'isGroupable',
            'is_evaluable': 'isEvaluable',
            'value_type': 'valueType',
            'original_display_name': 'originalDisplayName',
            'internal_name': 'internalName',
            'interval_gap': 'intervalGap',
            'intervals': 'intervals',
            'total_interval_counts': 'totalIntervalCounts',
            'total_interval_counts_after_filter': 'totalIntervalCountsAfterFilter',
            'interval_group_counts': 'intervalGroupCounts',
            'interval_group_counts_after_filter': 'intervalGroupCountsAfterFilter'
        }

        self._type = None
        self._display_name = None
        self._sub_system = None
        self._values = None
        self._is_list_of_values = None
        self._is_multi_valued = None
        self._is_groupable = None
        self._is_evaluable = None
        self._value_type = None
        self._original_display_name = None
        self._internal_name = None
        self._interval_gap = None
        self._intervals = None
        self._total_interval_counts = None
        self._total_interval_counts_after_filter = None
        self._interval_group_counts = None
        self._interval_group_counts_after_filter = None
        self._type = 'TREND_COLUMN'

    @property
    def interval_gap(self):
        """
        Gets the interval_gap of this TrendColumn.
        Time gap between each data pont in the series.


        :return: The interval_gap of this TrendColumn.
        :rtype: str
        """
        return self._interval_gap

    @interval_gap.setter
    def interval_gap(self, interval_gap):
        """
        Sets the interval_gap of this TrendColumn.
        Time gap between each data pont in the series.


        :param interval_gap: The interval_gap of this TrendColumn.
        :type: str
        """
        self._interval_gap = interval_gap

    @property
    def intervals(self):
        """
        Gets the intervals of this TrendColumn.
        Timestamps for each series data point


        :return: The intervals of this TrendColumn.
        :rtype: list[int]
        """
        return self._intervals

    @intervals.setter
    def intervals(self, intervals):
        """
        Sets the intervals of this TrendColumn.
        Timestamps for each series data point


        :param intervals: The intervals of this TrendColumn.
        :type: list[int]
        """
        self._intervals = intervals

    @property
    def total_interval_counts(self):
        """
        Gets the total_interval_counts of this TrendColumn.
        Sum across all column values for a given timestamp.


        :return: The total_interval_counts of this TrendColumn.
        :rtype: list[int]
        """
        return self._total_interval_counts

    @total_interval_counts.setter
    def total_interval_counts(self, total_interval_counts):
        """
        Sets the total_interval_counts of this TrendColumn.
        Sum across all column values for a given timestamp.


        :param total_interval_counts: The total_interval_counts of this TrendColumn.
        :type: list[int]
        """
        self._total_interval_counts = total_interval_counts

    @property
    def total_interval_counts_after_filter(self):
        """
        Gets the total_interval_counts_after_filter of this TrendColumn.

        :return: The total_interval_counts_after_filter of this TrendColumn.
        :rtype: list[int]
        """
        return self._total_interval_counts_after_filter

    @total_interval_counts_after_filter.setter
    def total_interval_counts_after_filter(self, total_interval_counts_after_filter):
        """
        Sets the total_interval_counts_after_filter of this TrendColumn.

        :param total_interval_counts_after_filter: The total_interval_counts_after_filter of this TrendColumn.
        :type: list[int]
        """
        self._total_interval_counts_after_filter = total_interval_counts_after_filter

    @property
    def interval_group_counts(self):
        """
        Gets the interval_group_counts of this TrendColumn.

        :return: The interval_group_counts of this TrendColumn.
        :rtype: list[int]
        """
        return self._interval_group_counts

    @interval_group_counts.setter
    def interval_group_counts(self, interval_group_counts):
        """
        Sets the interval_group_counts of this TrendColumn.

        :param interval_group_counts: The interval_group_counts of this TrendColumn.
        :type: list[int]
        """
        self._interval_group_counts = interval_group_counts

    @property
    def interval_group_counts_after_filter(self):
        """
        Gets the interval_group_counts_after_filter of this TrendColumn.

        :return: The interval_group_counts_after_filter of this TrendColumn.
        :rtype: list[int]
        """
        return self._interval_group_counts_after_filter

    @interval_group_counts_after_filter.setter
    def interval_group_counts_after_filter(self, interval_group_counts_after_filter):
        """
        Sets the interval_group_counts_after_filter of this TrendColumn.

        :param interval_group_counts_after_filter: The interval_group_counts_after_filter of this TrendColumn.
        :type: list[int]
        """
        self._interval_group_counts_after_filter = interval_group_counts_after_filter

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IdpGroupMapping(object):
    """
    A mapping between a single group defined by the identity provider (IdP) you're federating with
    and a single IAM Service :class:`Group` in Oracle Cloud Infrastructure.
    For more information about group mappings and what they're for, see
    `Identity Providers and Federation`__.

    A given IdP group can be mapped to zero, one, or multiple IAM Service groups, and vice versa.
    But each `IdPGroupMapping` object is between only a single IdP group and IAM Service group.
    Each `IdPGroupMapping` object has its own OCID.

    **Note:** Any users who are in more than 50 IdP groups cannot be authenticated to use the Oracle
    Cloud Infrastructure Console.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/federation.htm
    """

    #: A constant which can be used with the lifecycle_state property of a IdpGroupMapping.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a IdpGroupMapping.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a IdpGroupMapping.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a IdpGroupMapping.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a IdpGroupMapping.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new IdpGroupMapping object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this IdpGroupMapping.
        :type id: str

        :param idp_id:
            The value to assign to the idp_id property of this IdpGroupMapping.
        :type idp_id: str

        :param idp_group_name:
            The value to assign to the idp_group_name property of this IdpGroupMapping.
        :type idp_group_name: str

        :param group_id:
            The value to assign to the group_id property of this IdpGroupMapping.
        :type group_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this IdpGroupMapping.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this IdpGroupMapping.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this IdpGroupMapping.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param inactive_status:
            The value to assign to the inactive_status property of this IdpGroupMapping.
        :type inactive_status: int

        """
        self.swagger_types = {
            'id': 'str',
            'idp_id': 'str',
            'idp_group_name': 'str',
            'group_id': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'inactive_status': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'idp_id': 'idpId',
            'idp_group_name': 'idpGroupName',
            'group_id': 'groupId',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'inactive_status': 'inactiveStatus'
        }

        self._id = None
        self._idp_id = None
        self._idp_group_name = None
        self._group_id = None
        self._compartment_id = None
        self._time_created = None
        self._lifecycle_state = None
        self._inactive_status = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this IdpGroupMapping.
        The OCID of the `IdpGroupMapping`.


        :return: The id of this IdpGroupMapping.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IdpGroupMapping.
        The OCID of the `IdpGroupMapping`.


        :param id: The id of this IdpGroupMapping.
        :type: str
        """
        self._id = id

    @property
    def idp_id(self):
        """
        **[Required]** Gets the idp_id of this IdpGroupMapping.
        The OCID of the `IdentityProvider` this mapping belongs to.


        :return: The idp_id of this IdpGroupMapping.
        :rtype: str
        """
        return self._idp_id

    @idp_id.setter
    def idp_id(self, idp_id):
        """
        Sets the idp_id of this IdpGroupMapping.
        The OCID of the `IdentityProvider` this mapping belongs to.


        :param idp_id: The idp_id of this IdpGroupMapping.
        :type: str
        """
        self._idp_id = idp_id

    @property
    def idp_group_name(self):
        """
        **[Required]** Gets the idp_group_name of this IdpGroupMapping.
        The name of the IdP group that is mapped to the IAM Service group.


        :return: The idp_group_name of this IdpGroupMapping.
        :rtype: str
        """
        return self._idp_group_name

    @idp_group_name.setter
    def idp_group_name(self, idp_group_name):
        """
        Sets the idp_group_name of this IdpGroupMapping.
        The name of the IdP group that is mapped to the IAM Service group.


        :param idp_group_name: The idp_group_name of this IdpGroupMapping.
        :type: str
        """
        self._idp_group_name = idp_group_name

    @property
    def group_id(self):
        """
        **[Required]** Gets the group_id of this IdpGroupMapping.
        The OCID of the IAM Service group that is mapped to the IdP group.


        :return: The group_id of this IdpGroupMapping.
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """
        Sets the group_id of this IdpGroupMapping.
        The OCID of the IAM Service group that is mapped to the IdP group.


        :param group_id: The group_id of this IdpGroupMapping.
        :type: str
        """
        self._group_id = group_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this IdpGroupMapping.
        The OCID of the tenancy containing the `IdentityProvider`.


        :return: The compartment_id of this IdpGroupMapping.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this IdpGroupMapping.
        The OCID of the tenancy containing the `IdentityProvider`.


        :param compartment_id: The compartment_id of this IdpGroupMapping.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this IdpGroupMapping.
        Date and time the mapping was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this IdpGroupMapping.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this IdpGroupMapping.
        Date and time the mapping was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this IdpGroupMapping.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this IdpGroupMapping.
        The mapping's current state.  After creating a mapping object, make sure its `lifecycleState` changes
        from CREATING to ACTIVE before using it.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this IdpGroupMapping.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this IdpGroupMapping.
        The mapping's current state.  After creating a mapping object, make sure its `lifecycleState` changes
        from CREATING to ACTIVE before using it.


        :param lifecycle_state: The lifecycle_state of this IdpGroupMapping.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def inactive_status(self):
        """
        Gets the inactive_status of this IdpGroupMapping.
        The detailed status of INACTIVE lifecycleState.


        :return: The inactive_status of this IdpGroupMapping.
        :rtype: int
        """
        return self._inactive_status

    @inactive_status.setter
    def inactive_status(self, inactive_status):
        """
        Sets the inactive_status of this IdpGroupMapping.
        The detailed status of INACTIVE lifecycleState.


        :param inactive_status: The inactive_status of this IdpGroupMapping.
        :type: int
        """
        self._inactive_status = inactive_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataAssetDetails(object):
    """
    Properties used in data asset update operations.
    """

    #: A constant which can be used with the model_type property of a CreateDataAssetDetails.
    #: This constant has a value of "ORACLE_DATA_ASSET"
    MODEL_TYPE_ORACLE_DATA_ASSET = "ORACLE_DATA_ASSET"

    #: A constant which can be used with the model_type property of a CreateDataAssetDetails.
    #: This constant has a value of "ORACLE_OBJECT_STORAGE_DATA_ASSET"
    MODEL_TYPE_ORACLE_OBJECT_STORAGE_DATA_ASSET = "ORACLE_OBJECT_STORAGE_DATA_ASSET"

    #: A constant which can be used with the model_type property of a CreateDataAssetDetails.
    #: This constant has a value of "ORACLE_ATP_DATA_ASSET"
    MODEL_TYPE_ORACLE_ATP_DATA_ASSET = "ORACLE_ATP_DATA_ASSET"

    #: A constant which can be used with the model_type property of a CreateDataAssetDetails.
    #: This constant has a value of "ORACLE_ADWC_DATA_ASSET"
    MODEL_TYPE_ORACLE_ADWC_DATA_ASSET = "ORACLE_ADWC_DATA_ASSET"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataAssetDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.CreateDataAssetFromOracle`
        * :class:`~oci.data_integration.models.CreateDataAssetFromAdwc`
        * :class:`~oci.data_integration.models.CreateDataAssetFromAtp`
        * :class:`~oci.data_integration.models.CreateDataAssetFromObjectStorage`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this CreateDataAssetDetails.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET"
        :type model_type: str

        :param key:
            The value to assign to the key property of this CreateDataAssetDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateDataAssetDetails.
        :type model_version: str

        :param name:
            The value to assign to the name property of this CreateDataAssetDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateDataAssetDetails.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this CreateDataAssetDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateDataAssetDetails.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this CreateDataAssetDetails.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this CreateDataAssetDetails.
        :type asset_properties: dict(str, str)

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateDataAssetDetails.
        :type registry_metadata: RegistryMetadata

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'registry_metadata': 'registryMetadata'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._registry_metadata = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'ORACLE_DATA_ASSET':
            return 'CreateDataAssetFromOracle'

        if type == 'ORACLE_ADWC_DATA_ASSET':
            return 'CreateDataAssetFromAdwc'

        if type == 'ORACLE_ATP_DATA_ASSET':
            return 'CreateDataAssetFromAtp'

        if type == 'ORACLE_OBJECT_STORAGE_DATA_ASSET':
            return 'CreateDataAssetFromObjectStorage'
        else:
            return 'CreateDataAssetDetails'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this CreateDataAssetDetails.
        The type of the data asset.

        Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET"


        :return: The model_type of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this CreateDataAssetDetails.
        The type of the data asset.


        :param model_type: The model_type of this CreateDataAssetDetails.
        :type: str
        """
        allowed_values = ["ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            raise ValueError(
                "Invalid value for `model_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._model_type = model_type

    @property
    def key(self):
        """
        Gets the key of this CreateDataAssetDetails.
        Currently not used on data asset creation. Reserved for future.


        :return: The key of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this CreateDataAssetDetails.
        Currently not used on data asset creation. Reserved for future.


        :param key: The key of this CreateDataAssetDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this CreateDataAssetDetails.
        The model version of an object.


        :return: The model_version of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this CreateDataAssetDetails.
        The model version of an object.


        :param model_version: The model_version of this CreateDataAssetDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateDataAssetDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :return: The name of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateDataAssetDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :param name: The name of this CreateDataAssetDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreateDataAssetDetails.
        Detailed description for the object.


        :return: The description of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDataAssetDetails.
        Detailed description for the object.


        :param description: The description of this CreateDataAssetDetails.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this CreateDataAssetDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this CreateDataAssetDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this CreateDataAssetDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this CreateDataAssetDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this CreateDataAssetDetails.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :return: The identifier of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this CreateDataAssetDetails.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :param identifier: The identifier of this CreateDataAssetDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def external_key(self):
        """
        Gets the external_key of this CreateDataAssetDetails.
        The external key for the object


        :return: The external_key of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this CreateDataAssetDetails.
        The external key for the object


        :param external_key: The external_key of this CreateDataAssetDetails.
        :type: str
        """
        self._external_key = external_key

    @property
    def asset_properties(self):
        """
        Gets the asset_properties of this CreateDataAssetDetails.
        assetProperties


        :return: The asset_properties of this CreateDataAssetDetails.
        :rtype: dict(str, str)
        """
        return self._asset_properties

    @asset_properties.setter
    def asset_properties(self, asset_properties):
        """
        Sets the asset_properties of this CreateDataAssetDetails.
        assetProperties


        :param asset_properties: The asset_properties of this CreateDataAssetDetails.
        :type: dict(str, str)
        """
        self._asset_properties = asset_properties

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this CreateDataAssetDetails.

        :return: The registry_metadata of this CreateDataAssetDetails.
        :rtype: RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this CreateDataAssetDetails.

        :param registry_metadata: The registry_metadata of this CreateDataAssetDetails.
        :type: RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .security_token_signer import SecurityTokenSigner, X509FederationClientBasedSecurityTokenSigner  # noqa: F401
from .instance_principals_security_token_signer import InstancePrincipalsSecurityTokenSigner  # noqa: F401
from .instance_principals_delegation_token_signer import InstancePrincipalsDelegationTokenSigner  # noqa: F401
from .resource_principals_federation_signer import ResourcePrincipalsFederationSigner  # noqa: F401
from .ephemeral_resource_principals_signer import EphemeralResourcePrincipalSigner  # noqa: F401
from .resource_principals_signer import get_resource_principals_signer  # noqa: F401



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Resource(object):
    """
    Details about the ticket item object.
    """

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "DEV"
    REGION_DEV = "DEV"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "SEA"
    REGION_SEA = "SEA"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "INTEG_NEXT"
    REGION_INTEG_NEXT = "INTEG_NEXT"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "INTEG_STABLE"
    REGION_INTEG_STABLE = "INTEG_STABLE"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "PHX"
    REGION_PHX = "PHX"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "IAD"
    REGION_IAD = "IAD"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "FRA"
    REGION_FRA = "FRA"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "EU_FRANKFURT_1"
    REGION_EU_FRANKFURT_1 = "EU_FRANKFURT_1"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "LHR"
    REGION_LHR = "LHR"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "YYZ"
    REGION_YYZ = "YYZ"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "NRT"
    REGION_NRT = "NRT"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "ICN"
    REGION_ICN = "ICN"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "BOM"
    REGION_BOM = "BOM"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "GRU"
    REGION_GRU = "GRU"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "SYD"
    REGION_SYD = "SYD"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "ZRH"
    REGION_ZRH = "ZRH"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "JED"
    REGION_JED = "JED"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "AMS"
    REGION_AMS = "AMS"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "KIX"
    REGION_KIX = "KIX"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "MEL"
    REGION_MEL = "MEL"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "YUL"
    REGION_YUL = "YUL"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "HYD"
    REGION_HYD = "HYD"

    #: A constant which can be used with the region property of a Resource.
    #: This constant has a value of "YNY"
    REGION_YNY = "YNY"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "DEV_1"
    AVAILABILITY_DOMAIN_DEV_1 = "DEV_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "DEV_2"
    AVAILABILITY_DOMAIN_DEV_2 = "DEV_2"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "DEV_3"
    AVAILABILITY_DOMAIN_DEV_3 = "DEV_3"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "INTEG_NEXT_1"
    AVAILABILITY_DOMAIN_INTEG_NEXT_1 = "INTEG_NEXT_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "INTEG_STABLE_1"
    AVAILABILITY_DOMAIN_INTEG_STABLE_1 = "INTEG_STABLE_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "SEA_AD_1"
    AVAILABILITY_DOMAIN_SEA_AD_1 = "SEA_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "SEA_AD_2"
    AVAILABILITY_DOMAIN_SEA_AD_2 = "SEA_AD_2"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "SEA_AD_3"
    AVAILABILITY_DOMAIN_SEA_AD_3 = "SEA_AD_3"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "PHX_AD_1"
    AVAILABILITY_DOMAIN_PHX_AD_1 = "PHX_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "PHX_AD_2"
    AVAILABILITY_DOMAIN_PHX_AD_2 = "PHX_AD_2"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "PHX_AD_3"
    AVAILABILITY_DOMAIN_PHX_AD_3 = "PHX_AD_3"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "US_ASHBURN_AD_1"
    AVAILABILITY_DOMAIN_US_ASHBURN_AD_1 = "US_ASHBURN_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "US_ASHBURN_AD_2"
    AVAILABILITY_DOMAIN_US_ASHBURN_AD_2 = "US_ASHBURN_AD_2"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "US_ASHBURN_AD_3"
    AVAILABILITY_DOMAIN_US_ASHBURN_AD_3 = "US_ASHBURN_AD_3"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "US_ASHBURN_AD_4"
    AVAILABILITY_DOMAIN_US_ASHBURN_AD_4 = "US_ASHBURN_AD_4"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "EU_FRANKFURT_1_AD_1"
    AVAILABILITY_DOMAIN_EU_FRANKFURT_1_AD_1 = "EU_FRANKFURT_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "EU_FRANKFURT_1_AD_2"
    AVAILABILITY_DOMAIN_EU_FRANKFURT_1_AD_2 = "EU_FRANKFURT_1_AD_2"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "EU_FRANKFURT_1_AD_3"
    AVAILABILITY_DOMAIN_EU_FRANKFURT_1_AD_3 = "EU_FRANKFURT_1_AD_3"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "UK_LONDON_1_AD_1"
    AVAILABILITY_DOMAIN_UK_LONDON_1_AD_1 = "UK_LONDON_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "UK_LONDON_1_AD_2"
    AVAILABILITY_DOMAIN_UK_LONDON_1_AD_2 = "UK_LONDON_1_AD_2"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "UK_LONDON_1_AD_3"
    AVAILABILITY_DOMAIN_UK_LONDON_1_AD_3 = "UK_LONDON_1_AD_3"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "CA_TORONTO_1_AD_1"
    AVAILABILITY_DOMAIN_CA_TORONTO_1_AD_1 = "CA_TORONTO_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "AP_TOKYO_1_AD_1"
    AVAILABILITY_DOMAIN_AP_TOKYO_1_AD_1 = "AP_TOKYO_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "AP_SEOUL_1_AD_1"
    AVAILABILITY_DOMAIN_AP_SEOUL_1_AD_1 = "AP_SEOUL_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "AP_MUMBAI_1_AD_1"
    AVAILABILITY_DOMAIN_AP_MUMBAI_1_AD_1 = "AP_MUMBAI_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "SA_SAOPAULO_1_AD_1"
    AVAILABILITY_DOMAIN_SA_SAOPAULO_1_AD_1 = "SA_SAOPAULO_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "ME_JEDDAH_1_AD_1"
    AVAILABILITY_DOMAIN_ME_JEDDAH_1_AD_1 = "ME_JEDDAH_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "AP_OSAKA_1_AD_1"
    AVAILABILITY_DOMAIN_AP_OSAKA_1_AD_1 = "AP_OSAKA_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "AP_SYDNEY_1_AD_1"
    AVAILABILITY_DOMAIN_AP_SYDNEY_1_AD_1 = "AP_SYDNEY_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "EU_ZURICH_1_AD_1"
    AVAILABILITY_DOMAIN_EU_ZURICH_1_AD_1 = "EU_ZURICH_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "EU_AMSTERDAM_1_AD_1"
    AVAILABILITY_DOMAIN_EU_AMSTERDAM_1_AD_1 = "EU_AMSTERDAM_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "AP_MELBOURNE_1_AD_1"
    AVAILABILITY_DOMAIN_AP_MELBOURNE_1_AD_1 = "AP_MELBOURNE_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "CA_MONTREAL_1_AD_1"
    AVAILABILITY_DOMAIN_CA_MONTREAL_1_AD_1 = "CA_MONTREAL_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "AP_HYDERABAD_1_AD_1"
    AVAILABILITY_DOMAIN_AP_HYDERABAD_1_AD_1 = "AP_HYDERABAD_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "AP_CHUNCHEON_1_AD_1"
    AVAILABILITY_DOMAIN_AP_CHUNCHEON_1_AD_1 = "AP_CHUNCHEON_1_AD_1"

    #: A constant which can be used with the availability_domain property of a Resource.
    #: This constant has a value of "NO_AD"
    AVAILABILITY_DOMAIN_NO_AD = "NO_AD"

    def __init__(self, **kwargs):
        """
        Initializes a new Resource object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param item:
            The value to assign to the item property of this Resource.
        :type item: Item

        :param region:
            The value to assign to the region property of this Resource.
            Allowed values for this property are: "DEV", "SEA", "INTEG_NEXT", "INTEG_STABLE", "PHX", "IAD", "FRA", "EU_FRANKFURT_1", "LHR", "YYZ", "NRT", "ICN", "BOM", "GRU", "SYD", "ZRH", "JED", "AMS", "KIX", "MEL", "YUL", "HYD", "YNY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type region: str

        :param availability_domain:
            The value to assign to the availability_domain property of this Resource.
            Allowed values for this property are: "DEV_1", "DEV_2", "DEV_3", "INTEG_NEXT_1", "INTEG_STABLE_1", "SEA_AD_1", "SEA_AD_2", "SEA_AD_3", "PHX_AD_1", "PHX_AD_2", "PHX_AD_3", "US_ASHBURN_AD_1", "US_ASHBURN_AD_2", "US_ASHBURN_AD_3", "US_ASHBURN_AD_4", "EU_FRANKFURT_1_AD_1", "EU_FRANKFURT_1_AD_2", "EU_FRANKFURT_1_AD_3", "UK_LONDON_1_AD_1", "UK_LONDON_1_AD_2", "UK_LONDON_1_AD_3", "CA_TORONTO_1_AD_1", "AP_TOKYO_1_AD_1", "AP_SEOUL_1_AD_1", "AP_MUMBAI_1_AD_1", "SA_SAOPAULO_1_AD_1", "ME_JEDDAH_1_AD_1", "AP_OSAKA_1_AD_1", "AP_SYDNEY_1_AD_1", "EU_ZURICH_1_AD_1", "EU_AMSTERDAM_1_AD_1", "AP_MELBOURNE_1_AD_1", "CA_MONTREAL_1_AD_1", "AP_HYDERABAD_1_AD_1", "AP_CHUNCHEON_1_AD_1", "NO_AD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type availability_domain: str

        """
        self.swagger_types = {
            'item': 'Item',
            'region': 'str',
            'availability_domain': 'str'
        }

        self.attribute_map = {
            'item': 'item',
            'region': 'region',
            'availability_domain': 'availabilityDomain'
        }

        self._item = None
        self._region = None
        self._availability_domain = None

    @property
    def item(self):
        """
        Gets the item of this Resource.

        :return: The item of this Resource.
        :rtype: Item
        """
        return self._item

    @item.setter
    def item(self, item):
        """
        Sets the item of this Resource.

        :param item: The item of this Resource.
        :type: Item
        """
        self._item = item

    @property
    def region(self):
        """
        Gets the region of this Resource.
        The list of available Oracle Cloud Infrastructure regions.

        Allowed values for this property are: "DEV", "SEA", "INTEG_NEXT", "INTEG_STABLE", "PHX", "IAD", "FRA", "EU_FRANKFURT_1", "LHR", "YYZ", "NRT", "ICN", "BOM", "GRU", "SYD", "ZRH", "JED", "AMS", "KIX", "MEL", "YUL", "HYD", "YNY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The region of this Resource.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this Resource.
        The list of available Oracle Cloud Infrastructure regions.


        :param region: The region of this Resource.
        :type: str
        """
        allowed_values = ["DEV", "SEA", "INTEG_NEXT", "INTEG_STABLE", "PHX", "IAD", "FRA", "EU_FRANKFURT_1", "LHR", "YYZ", "NRT", "ICN", "BOM", "GRU", "SYD", "ZRH", "JED", "AMS", "KIX", "MEL", "YUL", "HYD", "YNY"]
        if not value_allowed_none_or_none_sentinel(region, allowed_values):
            region = 'UNKNOWN_ENUM_VALUE'
        self._region = region

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this Resource.
        The list of available Oracle Cloud Infrastructure availability domains.

        Allowed values for this property are: "DEV_1", "DEV_2", "DEV_3", "INTEG_NEXT_1", "INTEG_STABLE_1", "SEA_AD_1", "SEA_AD_2", "SEA_AD_3", "PHX_AD_1", "PHX_AD_2", "PHX_AD_3", "US_ASHBURN_AD_1", "US_ASHBURN_AD_2", "US_ASHBURN_AD_3", "US_ASHBURN_AD_4", "EU_FRANKFURT_1_AD_1", "EU_FRANKFURT_1_AD_2", "EU_FRANKFURT_1_AD_3", "UK_LONDON_1_AD_1", "UK_LONDON_1_AD_2", "UK_LONDON_1_AD_3", "CA_TORONTO_1_AD_1", "AP_TOKYO_1_AD_1", "AP_SEOUL_1_AD_1", "AP_MUMBAI_1_AD_1", "SA_SAOPAULO_1_AD_1", "ME_JEDDAH_1_AD_1", "AP_OSAKA_1_AD_1", "AP_SYDNEY_1_AD_1", "EU_ZURICH_1_AD_1", "EU_AMSTERDAM_1_AD_1", "AP_MELBOURNE_1_AD_1", "CA_MONTREAL_1_AD_1", "AP_HYDERABAD_1_AD_1", "AP_CHUNCHEON_1_AD_1", "NO_AD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The availability_domain of this Resource.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this Resource.
        The list of available Oracle Cloud Infrastructure availability domains.


        :param availability_domain: The availability_domain of this Resource.
        :type: str
        """
        allowed_values = ["DEV_1", "DEV_2", "DEV_3", "INTEG_NEXT_1", "INTEG_STABLE_1", "SEA_AD_1", "SEA_AD_2", "SEA_AD_3", "PHX_AD_1", "PHX_AD_2", "PHX_AD_3", "US_ASHBURN_AD_1", "US_ASHBURN_AD_2", "US_ASHBURN_AD_3", "US_ASHBURN_AD_4", "EU_FRANKFURT_1_AD_1", "EU_FRANKFURT_1_AD_2", "EU_FRANKFURT_1_AD_3", "UK_LONDON_1_AD_1", "UK_LONDON_1_AD_2", "UK_LONDON_1_AD_3", "CA_TORONTO_1_AD_1", "AP_TOKYO_1_AD_1", "AP_SEOUL_1_AD_1", "AP_MUMBAI_1_AD_1", "SA_SAOPAULO_1_AD_1", "ME_JEDDAH_1_AD_1", "AP_OSAKA_1_AD_1", "AP_SYDNEY_1_AD_1", "EU_ZURICH_1_AD_1", "EU_AMSTERDAM_1_AD_1", "AP_MELBOURNE_1_AD_1", "CA_MONTREAL_1_AD_1", "AP_HYDERABAD_1_AD_1", "AP_CHUNCHEON_1_AD_1", "NO_AD"]
        if not value_allowed_none_or_none_sentinel(availability_domain, allowed_values):
            availability_domain = 'UNKNOWN_ENUM_VALUE'
        self._availability_domain = availability_domain

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateVmClusterDetails(object):
    """
    Details for the create VM cluster operation.
    """

    #: A constant which can be used with the license_model property of a CreateVmClusterDetails.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a CreateVmClusterDetails.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateVmClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateVmClusterDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateVmClusterDetails.
        :type display_name: str

        :param exadata_infrastructure_id:
            The value to assign to the exadata_infrastructure_id property of this CreateVmClusterDetails.
        :type exadata_infrastructure_id: str

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this CreateVmClusterDetails.
        :type cpu_core_count: int

        :param memory_size_in_gbs:
            The value to assign to the memory_size_in_gbs property of this CreateVmClusterDetails.
        :type memory_size_in_gbs: int

        :param db_node_storage_size_in_gbs:
            The value to assign to the db_node_storage_size_in_gbs property of this CreateVmClusterDetails.
        :type db_node_storage_size_in_gbs: int

        :param data_storage_size_in_tbs:
            The value to assign to the data_storage_size_in_tbs property of this CreateVmClusterDetails.
        :type data_storage_size_in_tbs: float

        :param ssh_public_keys:
            The value to assign to the ssh_public_keys property of this CreateVmClusterDetails.
        :type ssh_public_keys: list[str]

        :param vm_cluster_network_id:
            The value to assign to the vm_cluster_network_id property of this CreateVmClusterDetails.
        :type vm_cluster_network_id: str

        :param license_model:
            The value to assign to the license_model property of this CreateVmClusterDetails.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"
        :type license_model: str

        :param is_sparse_diskgroup_enabled:
            The value to assign to the is_sparse_diskgroup_enabled property of this CreateVmClusterDetails.
        :type is_sparse_diskgroup_enabled: bool

        :param is_local_backup_enabled:
            The value to assign to the is_local_backup_enabled property of this CreateVmClusterDetails.
        :type is_local_backup_enabled: bool

        :param time_zone:
            The value to assign to the time_zone property of this CreateVmClusterDetails.
        :type time_zone: str

        :param gi_version:
            The value to assign to the gi_version property of this CreateVmClusterDetails.
        :type gi_version: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateVmClusterDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateVmClusterDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'exadata_infrastructure_id': 'str',
            'cpu_core_count': 'int',
            'memory_size_in_gbs': 'int',
            'db_node_storage_size_in_gbs': 'int',
            'data_storage_size_in_tbs': 'float',
            'ssh_public_keys': 'list[str]',
            'vm_cluster_network_id': 'str',
            'license_model': 'str',
            'is_sparse_diskgroup_enabled': 'bool',
            'is_local_backup_enabled': 'bool',
            'time_zone': 'str',
            'gi_version': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'exadata_infrastructure_id': 'exadataInfrastructureId',
            'cpu_core_count': 'cpuCoreCount',
            'memory_size_in_gbs': 'memorySizeInGBs',
            'db_node_storage_size_in_gbs': 'dbNodeStorageSizeInGBs',
            'data_storage_size_in_tbs': 'dataStorageSizeInTBs',
            'ssh_public_keys': 'sshPublicKeys',
            'vm_cluster_network_id': 'vmClusterNetworkId',
            'license_model': 'licenseModel',
            'is_sparse_diskgroup_enabled': 'isSparseDiskgroupEnabled',
            'is_local_backup_enabled': 'isLocalBackupEnabled',
            'time_zone': 'timeZone',
            'gi_version': 'giVersion',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._exadata_infrastructure_id = None
        self._cpu_core_count = None
        self._memory_size_in_gbs = None
        self._db_node_storage_size_in_gbs = None
        self._data_storage_size_in_tbs = None
        self._ssh_public_keys = None
        self._vm_cluster_network_id = None
        self._license_model = None
        self._is_sparse_diskgroup_enabled = None
        self._is_local_backup_enabled = None
        self._time_zone = None
        self._gi_version = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateVmClusterDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateVmClusterDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateVmClusterDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateVmClusterDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateVmClusterDetails.
        The user-friendly name for the VM cluster. The name does not need to be unique.


        :return: The display_name of this CreateVmClusterDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateVmClusterDetails.
        The user-friendly name for the VM cluster. The name does not need to be unique.


        :param display_name: The display_name of this CreateVmClusterDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def exadata_infrastructure_id(self):
        """
        **[Required]** Gets the exadata_infrastructure_id of this CreateVmClusterDetails.
        The `OCID`__ of the Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The exadata_infrastructure_id of this CreateVmClusterDetails.
        :rtype: str
        """
        return self._exadata_infrastructure_id

    @exadata_infrastructure_id.setter
    def exadata_infrastructure_id(self, exadata_infrastructure_id):
        """
        Sets the exadata_infrastructure_id of this CreateVmClusterDetails.
        The `OCID`__ of the Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param exadata_infrastructure_id: The exadata_infrastructure_id of this CreateVmClusterDetails.
        :type: str
        """
        self._exadata_infrastructure_id = exadata_infrastructure_id

    @property
    def cpu_core_count(self):
        """
        **[Required]** Gets the cpu_core_count of this CreateVmClusterDetails.
        The number of CPU cores to enable for the VM cluster.


        :return: The cpu_core_count of this CreateVmClusterDetails.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this CreateVmClusterDetails.
        The number of CPU cores to enable for the VM cluster.


        :param cpu_core_count: The cpu_core_count of this CreateVmClusterDetails.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def memory_size_in_gbs(self):
        """
        Gets the memory_size_in_gbs of this CreateVmClusterDetails.
        The memory to be allocated in GBs.


        :return: The memory_size_in_gbs of this CreateVmClusterDetails.
        :rtype: int
        """
        return self._memory_size_in_gbs

    @memory_size_in_gbs.setter
    def memory_size_in_gbs(self, memory_size_in_gbs):
        """
        Sets the memory_size_in_gbs of this CreateVmClusterDetails.
        The memory to be allocated in GBs.


        :param memory_size_in_gbs: The memory_size_in_gbs of this CreateVmClusterDetails.
        :type: int
        """
        self._memory_size_in_gbs = memory_size_in_gbs

    @property
    def db_node_storage_size_in_gbs(self):
        """
        Gets the db_node_storage_size_in_gbs of this CreateVmClusterDetails.
        The local node storage to be allocated in GBs.


        :return: The db_node_storage_size_in_gbs of this CreateVmClusterDetails.
        :rtype: int
        """
        return self._db_node_storage_size_in_gbs

    @db_node_storage_size_in_gbs.setter
    def db_node_storage_size_in_gbs(self, db_node_storage_size_in_gbs):
        """
        Sets the db_node_storage_size_in_gbs of this CreateVmClusterDetails.
        The local node storage to be allocated in GBs.


        :param db_node_storage_size_in_gbs: The db_node_storage_size_in_gbs of this CreateVmClusterDetails.
        :type: int
        """
        self._db_node_storage_size_in_gbs = db_node_storage_size_in_gbs

    @property
    def data_storage_size_in_tbs(self):
        """
        Gets the data_storage_size_in_tbs of this CreateVmClusterDetails.
        The data disk group size to be allocated in TBs.


        :return: The data_storage_size_in_tbs of this CreateVmClusterDetails.
        :rtype: float
        """
        return self._data_storage_size_in_tbs

    @data_storage_size_in_tbs.setter
    def data_storage_size_in_tbs(self, data_storage_size_in_tbs):
        """
        Sets the data_storage_size_in_tbs of this CreateVmClusterDetails.
        The data disk group size to be allocated in TBs.


        :param data_storage_size_in_tbs: The data_storage_size_in_tbs of this CreateVmClusterDetails.
        :type: float
        """
        self._data_storage_size_in_tbs = data_storage_size_in_tbs

    @property
    def ssh_public_keys(self):
        """
        **[Required]** Gets the ssh_public_keys of this CreateVmClusterDetails.
        The public key portion of one or more key pairs used for SSH access to the VM cluster.


        :return: The ssh_public_keys of this CreateVmClusterDetails.
        :rtype: list[str]
        """
        return self._ssh_public_keys

    @ssh_public_keys.setter
    def ssh_public_keys(self, ssh_public_keys):
        """
        Sets the ssh_public_keys of this CreateVmClusterDetails.
        The public key portion of one or more key pairs used for SSH access to the VM cluster.


        :param ssh_public_keys: The ssh_public_keys of this CreateVmClusterDetails.
        :type: list[str]
        """
        self._ssh_public_keys = ssh_public_keys

    @property
    def vm_cluster_network_id(self):
        """
        **[Required]** Gets the vm_cluster_network_id of this CreateVmClusterDetails.
        The `OCID`__ of the VM cluster network.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vm_cluster_network_id of this CreateVmClusterDetails.
        :rtype: str
        """
        return self._vm_cluster_network_id

    @vm_cluster_network_id.setter
    def vm_cluster_network_id(self, vm_cluster_network_id):
        """
        Sets the vm_cluster_network_id of this CreateVmClusterDetails.
        The `OCID`__ of the VM cluster network.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vm_cluster_network_id: The vm_cluster_network_id of this CreateVmClusterDetails.
        :type: str
        """
        self._vm_cluster_network_id = vm_cluster_network_id

    @property
    def license_model(self):
        """
        Gets the license_model of this CreateVmClusterDetails.
        The Oracle license model that applies to the VM cluster. The default is BRING_YOUR_OWN_LICENSE.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"


        :return: The license_model of this CreateVmClusterDetails.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this CreateVmClusterDetails.
        The Oracle license model that applies to the VM cluster. The default is BRING_YOUR_OWN_LICENSE.


        :param license_model: The license_model of this CreateVmClusterDetails.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            raise ValueError(
                "Invalid value for `license_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._license_model = license_model

    @property
    def is_sparse_diskgroup_enabled(self):
        """
        Gets the is_sparse_diskgroup_enabled of this CreateVmClusterDetails.
        If true, the sparse disk group is configured for the VM cluster. If false, the sparse disk group is not created.


        :return: The is_sparse_diskgroup_enabled of this CreateVmClusterDetails.
        :rtype: bool
        """
        return self._is_sparse_diskgroup_enabled

    @is_sparse_diskgroup_enabled.setter
    def is_sparse_diskgroup_enabled(self, is_sparse_diskgroup_enabled):
        """
        Sets the is_sparse_diskgroup_enabled of this CreateVmClusterDetails.
        If true, the sparse disk group is configured for the VM cluster. If false, the sparse disk group is not created.


        :param is_sparse_diskgroup_enabled: The is_sparse_diskgroup_enabled of this CreateVmClusterDetails.
        :type: bool
        """
        self._is_sparse_diskgroup_enabled = is_sparse_diskgroup_enabled

    @property
    def is_local_backup_enabled(self):
        """
        Gets the is_local_backup_enabled of this CreateVmClusterDetails.
        If true, database backup on local Exadata storage is configured for the VM cluster. If false, database backup on local Exadata storage is not available in the VM cluster.


        :return: The is_local_backup_enabled of this CreateVmClusterDetails.
        :rtype: bool
        """
        return self._is_local_backup_enabled

    @is_local_backup_enabled.setter
    def is_local_backup_enabled(self, is_local_backup_enabled):
        """
        Sets the is_local_backup_enabled of this CreateVmClusterDetails.
        If true, database backup on local Exadata storage is configured for the VM cluster. If false, database backup on local Exadata storage is not available in the VM cluster.


        :param is_local_backup_enabled: The is_local_backup_enabled of this CreateVmClusterDetails.
        :type: bool
        """
        self._is_local_backup_enabled = is_local_backup_enabled

    @property
    def time_zone(self):
        """
        Gets the time_zone of this CreateVmClusterDetails.
        The time zone to use for the VM cluster. For details, see `DB System Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :return: The time_zone of this CreateVmClusterDetails.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this CreateVmClusterDetails.
        The time zone to use for the VM cluster. For details, see `DB System Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :param time_zone: The time_zone of this CreateVmClusterDetails.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def gi_version(self):
        """
        **[Required]** Gets the gi_version of this CreateVmClusterDetails.
        The Oracle Grid Infrastructure software version for the VM cluster.


        :return: The gi_version of this CreateVmClusterDetails.
        :rtype: str
        """
        return self._gi_version

    @gi_version.setter
    def gi_version(self, gi_version):
        """
        Sets the gi_version of this CreateVmClusterDetails.
        The Oracle Grid Infrastructure software version for the VM cluster.


        :param gi_version: The gi_version of this CreateVmClusterDetails.
        :type: str
        """
        self._gi_version = gi_version

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateVmClusterDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateVmClusterDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateVmClusterDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateVmClusterDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .base_tag_definition_validator import BaseTagDefinitionValidator
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DefaultTagDefinitionValidator(BaseTagDefinitionValidator):
    """
    Use this validator to clear any existing validator on the tag key definition with the UpdateTag
    operation. Using this `validatorType` is the same as not setting any value on the validator field.
    The resultant value for `validatorType` returned in the response body is `null`.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DefaultTagDefinitionValidator object with values from keyword arguments. The default value of the :py:attr:`~oci.identity.models.DefaultTagDefinitionValidator.validator_type` attribute
        of this class is ``DEFAULT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param validator_type:
            The value to assign to the validator_type property of this DefaultTagDefinitionValidator.
            Allowed values for this property are: "ENUM", "DEFAULT"
        :type validator_type: str

        """
        self.swagger_types = {
            'validator_type': 'str'
        }

        self.attribute_map = {
            'validator_type': 'validatorType'
        }

        self._validator_type = None
        self._validator_type = 'DEFAULT'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExportKeyDetails(object):
    """
    The details of the key that you want to wrap and export.
    """

    #: A constant which can be used with the algorithm property of a ExportKeyDetails.
    #: This constant has a value of "RSA_OAEP_AES_SHA256"
    ALGORITHM_RSA_OAEP_AES_SHA256 = "RSA_OAEP_AES_SHA256"

    #: A constant which can be used with the algorithm property of a ExportKeyDetails.
    #: This constant has a value of "RSA_OAEP_SHA256"
    ALGORITHM_RSA_OAEP_SHA256 = "RSA_OAEP_SHA256"

    def __init__(self, **kwargs):
        """
        Initializes a new ExportKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key_id:
            The value to assign to the key_id property of this ExportKeyDetails.
        :type key_id: str

        :param key_version_id:
            The value to assign to the key_version_id property of this ExportKeyDetails.
        :type key_version_id: str

        :param algorithm:
            The value to assign to the algorithm property of this ExportKeyDetails.
            Allowed values for this property are: "RSA_OAEP_AES_SHA256", "RSA_OAEP_SHA256"
        :type algorithm: str

        :param public_key:
            The value to assign to the public_key property of this ExportKeyDetails.
        :type public_key: str

        :param logging_context:
            The value to assign to the logging_context property of this ExportKeyDetails.
        :type logging_context: dict(str, str)

        """
        self.swagger_types = {
            'key_id': 'str',
            'key_version_id': 'str',
            'algorithm': 'str',
            'public_key': 'str',
            'logging_context': 'dict(str, str)'
        }

        self.attribute_map = {
            'key_id': 'keyId',
            'key_version_id': 'keyVersionId',
            'algorithm': 'algorithm',
            'public_key': 'publicKey',
            'logging_context': 'loggingContext'
        }

        self._key_id = None
        self._key_version_id = None
        self._algorithm = None
        self._public_key = None
        self._logging_context = None

    @property
    def key_id(self):
        """
        **[Required]** Gets the key_id of this ExportKeyDetails.
        The OCID of the master encryption key associated with the key version you want to export.


        :return: The key_id of this ExportKeyDetails.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this ExportKeyDetails.
        The OCID of the master encryption key associated with the key version you want to export.


        :param key_id: The key_id of this ExportKeyDetails.
        :type: str
        """
        self._key_id = key_id

    @property
    def key_version_id(self):
        """
        Gets the key_version_id of this ExportKeyDetails.
        The OCID of the specific key version to export. If not specified, the service exports the current key version.


        :return: The key_version_id of this ExportKeyDetails.
        :rtype: str
        """
        return self._key_version_id

    @key_version_id.setter
    def key_version_id(self, key_version_id):
        """
        Sets the key_version_id of this ExportKeyDetails.
        The OCID of the specific key version to export. If not specified, the service exports the current key version.


        :param key_version_id: The key_version_id of this ExportKeyDetails.
        :type: str
        """
        self._key_version_id = key_version_id

    @property
    def algorithm(self):
        """
        **[Required]** Gets the algorithm of this ExportKeyDetails.
        The encryption algorithm to use to encrypt exportable key material from a software-backed key. Specifying `RSA_OAEP_AES_SHA256`
        invokes the RSA AES key wrap mechanism, which generates a temporary AES key. The temporary AES key is wrapped by the RSA public
        wrapping key provided along with the request, creating a wrapped temporary AES key. The temporary AES key is also used to wrap
        the exportable key material. The wrapped temporary AES key and the wrapped exportable key material are concatenated, producing
        concatenated blob output that jointly represents them. Specifying `RSA_OAEP_SHA256` means that the software key is wrapped by
        the RSA public wrapping key provided along with the request.

        Allowed values for this property are: "RSA_OAEP_AES_SHA256", "RSA_OAEP_SHA256"


        :return: The algorithm of this ExportKeyDetails.
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """
        Sets the algorithm of this ExportKeyDetails.
        The encryption algorithm to use to encrypt exportable key material from a software-backed key. Specifying `RSA_OAEP_AES_SHA256`
        invokes the RSA AES key wrap mechanism, which generates a temporary AES key. The temporary AES key is wrapped by the RSA public
        wrapping key provided along with the request, creating a wrapped temporary AES key. The temporary AES key is also used to wrap
        the exportable key material. The wrapped temporary AES key and the wrapped exportable key material are concatenated, producing
        concatenated blob output that jointly represents them. Specifying `RSA_OAEP_SHA256` means that the software key is wrapped by
        the RSA public wrapping key provided along with the request.


        :param algorithm: The algorithm of this ExportKeyDetails.
        :type: str
        """
        allowed_values = ["RSA_OAEP_AES_SHA256", "RSA_OAEP_SHA256"]
        if not value_allowed_none_or_none_sentinel(algorithm, allowed_values):
            raise ValueError(
                "Invalid value for `algorithm`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._algorithm = algorithm

    @property
    def public_key(self):
        """
        **[Required]** Gets the public_key of this ExportKeyDetails.
        The PEM format of the 2048-bit, 3072-bit, or 4096-bit RSA wrapping key in your possession that you want to use to encrypt the key.


        :return: The public_key of this ExportKeyDetails.
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """
        Sets the public_key of this ExportKeyDetails.
        The PEM format of the 2048-bit, 3072-bit, or 4096-bit RSA wrapping key in your possession that you want to use to encrypt the key.


        :param public_key: The public_key of this ExportKeyDetails.
        :type: str
        """
        self._public_key = public_key

    @property
    def logging_context(self):
        """
        Gets the logging_context of this ExportKeyDetails.
        Information that provides context for audit logging. You can provide this additional
        data as key-value pairs to include in the audit logs when audit logging is enabled.


        :return: The logging_context of this ExportKeyDetails.
        :rtype: dict(str, str)
        """
        return self._logging_context

    @logging_context.setter
    def logging_context(self, logging_context):
        """
        Sets the logging_context of this ExportKeyDetails.
        Information that provides context for audit logging. You can provide this additional
        data as key-value pairs to include in the audit logs when audit logging is enabled.


        :param logging_context: The logging_context of this ExportKeyDetails.
        :type: dict(str, str)
        """
        self._logging_context = logging_context

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
